library rest_api_helper;

import 'dart:io';
import 'package:http/http.dart' as http;
import 'package:rest_api_helper/exceptions/custom_exception.dart';
import './helper/helper.dart';

class RestApiHelper {
  String baseUrl;
  RestApiHelper({required this.baseUrl});
  //Post Request Method
  Future<dynamic> getRequest({
    required String url,
    Map<String, String>? headers,
  }) async {
    final Uri parsedURL = parseURL(url: url, baseUrl: baseUrl);
    dynamic responseJson;
    try {
      final response = await http.get(
        parsedURL,
        headers: headers,
      );
      responseJson = responseCheck(response);
    } on SocketException {
      throw InternetConnectionException(message: 'No Internet Connection');
    }
    return responseJson;
  }

  //Get Request Method
  Future<dynamic> postRequest({
    required String url,
    Map<String, dynamic>? body,
    Map<String, String>? headers,
  }) async {
    final Uri parsedURL = parseURL(url: url, baseUrl: baseUrl);
    dynamic responseJson;
    try {
      final response = await http.post(
        parsedURL,
        headers: headers,
        body: body,
      );
      responseJson = responseCheck(response);
    } on SocketException {
      throw InternetConnectionException(message: 'No Internet Connection');
    }
    return responseJson;
  }

  //Put Request Method
  Future<dynamic> putRequest({
    required String url,
    Map<String, dynamic>? body,
    Map<String, String>? headers,
  }) async {
    final Uri parsedURL = parseURL(url: url, baseUrl: baseUrl);
    dynamic responseJson;
    try {
      final response = await http.put(
        parsedURL,
        headers: headers,
        body: body,
      );
      responseJson = responseCheck(response);
    } on SocketException {
      throw InternetConnectionException(message: 'No Internet Connection');
    }
    return responseJson;
  }

  //Delete Request Method
  Future<dynamic> deleteRequest({
    required String url,
    Map<String, dynamic>? body,
    Map<String, String>? headers,
  }) async {
    final Uri parsedURL = parseURL(url: url, baseUrl: baseUrl);
    dynamic responseJson;
    try {
      final response = await http.delete(
        parsedURL,
        headers: headers,
        body: body,
      );
      responseJson = responseCheck(response);
    } on SocketException {
      throw InternetConnectionException(message: 'No Internet Connection');
    }
    return responseJson;
  }
  //Set Base Url
}
